abacusai.deployment_auth_token — AbacusAI documentation

# abacusai.deployment_auth_token

## Classes

`DeploymentAuthToken` | A deployment authentication token that is used to authenticate prediction requests

## Module Contents

class abacusai.deployment_auth_token.DeploymentAuthToken(client, deploymentToken=None, createdAt=None, name=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A deployment authentication token that is used to authenticate prediction requests

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - deploymentToken (str) – The unique token used to authenticate requests.

    - createdAt (str) – The date and time when the token was created, in ISO-8601 format.

    - name (str) – The name associated with the authentication token.

  deployment_token
  created_at
  name
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict